UpField<T> class

Inheritance
Mixed-in types
  • EqualoneMixin

Constructors

UpField({Key? key, String? label, bool enabled = true, bool mandatory = false, T? initialValue, FormFieldValidator<T>? validator, UpFieldSubmitter<T>? submitter, UpFormDependency? dependency, UpFieldKey<T>? formFieldKey, List components = const [], required Widget child})
UpField.named({required String name, String? label, bool enabled = true, bool mandatory = false, T? initialValue, FormFieldValidator<T>? validator, UpFieldSubmitter<T>? submitter, UpFormDependency? dependency, UpFieldKey<T>? formFieldKey, List components = const [], required Widget child})

Properties

child Widget
final
components List
final
dependency UpFormDependency?
final
enabled bool
final
equalones List<Object?>
no setteroverride
formFieldKey UpFieldKey<T>?
final
hashCode int
The hash code for this object.
no setterinherited
initialValue → T?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
mandatory bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submitter UpFieldSubmitter<T>?
if not set, the form.submitter(field) will be used
final
validator FormFieldValidator<T>?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<UpField<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

find<T>(BuildContext context) UpFieldState<T>?
maybeOf<T>(BuildContext context, {UpFieldModelCallback<T>? watch, Object? watchId}) UpFieldState<T>?
of<T>(BuildContext context, {UpFieldModelCallback<T>? watch, Object? watchId}) UpFieldState<T>
useOf<T>(BuildContext context) UpFieldState<T>
useWatch<T>(UpFieldModel<T> model) Object?
valueOf<T, V>(BuildContext context, {UpFieldModelValueCallback<T, V>? value, UpFieldModelCallback<T>? watch, Object? watchId}) → V?