UpFieldState<T> class

Inheritance
Available extensions

Constructors

UpFieldState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
enabled bool
no setter
errorText String?
no setter
fieldError String?
no setter
fieldKey UpFieldKey<T>
latefinal
forceError String?
no setter
form UpFormState
no setter
hasChanged bool
no setter
hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
id Object?
no setter
initialValue → T?
no setter
isEmpty bool
no setter
isNotEmpty bool
no setter
label String?
no setter
mandatory bool
no setter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
name String?
no setter
notifier ChangeNotifier
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submitter UpFieldSubmitter<T>?
no setter
validator FormFieldValidator<T>
no setter
value → T?
no setter
widget UpField<T>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
override
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildFormField({required FormFieldBuilder<T> builder, FormFieldErrorBuilder? errorBuilder, AutovalidateMode? autovalidateMode, bool? enabled, String? restorationId}) FormField<T>
deactivate() → void
Called when this object is removed from the tree.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decoration({InputDecoration? decoration, bool ignoreDecorationComponent = false}) InputDecoration
didChange(T? value) → void
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant UpField<T> oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
focusNode([UpFieldComponentCreator<FocusNode, dynamic>? create]) FocusNode
getComponent<C extends Object>(UpFieldComponentCreator<C, T> create, {UpFieldComponentDisposer<C>? dispose}) → C
initState() → void
Called when this object is inserted into the tree.
override
maybeComponent<C extends Object>() → C?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
registerComponent<C extends Object>(UpFieldComponentDelegate<C, T> component) → C
reset() → void
setState([VoidCallback fn = UpForm._noop]) → void
Notify the framework that the internal state of this object has changed.
override
submit() FutureOr<void>
textController({UpFieldComponentCreator<TextEditingController, String>? create, bool resetErrorOnChange = true}) TextEditingController

Available on UpFieldState<String>, provided by the UpTextFieldStateEx extension

textFormFieldBuilder(TextFormField builder(UpFieldState<String> field)) Widget

Available on UpFieldState<String>, provided by the UpTextFieldStateEx extension

Use this method to build a TextFormField bound to this UpFieldState:
textInputSubmit(TextInputAction? inputAction) FutureOr<void>

Available on UpFieldState<String>, provided by the UpTextFieldStateEx extension

textInputSubmitter(TextInputAction? inputAction) → void Function(dynamic)

Available on UpFieldState<String>, provided by the UpTextFieldStateEx extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
override
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validate() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited